Change history — PyEPR 0.3 documentation

### Navigation

- index
- modules |
- previous |
- PyEPR 0.3 documentation »

# Change history

## PyEPR 0.3 (01/04/2011)

- version string of the EPR C API is now exposed as module attribute `epr.EPR_C_API_VERSION`
- implemented `__repr__`, `__str__`, `__eq__`, `__ne__` and `__iter__` special methods
- added utility methods (not included in the C API) like:
  - `epr.Record.get_field_names()`
  - `epr.Record.fields()`
  - `epr.Dataset.records()`
  - `epr.Product.get_dataset_names()`
  - `epr.Product.get_band_names()`
  - `epr.Product.datasets()`
  - `epr.Product.bands()`
- fixed a logic error that caused empty messages in custom EPR exceptions

## PyEPR 0.2 (20/03/2011)

- sphinx documentation added
- added docstrings to all method and classes
- renamed some method and parameter in order to avoid redundancies and have a more pythonic API
- in case of null pointers a `EPRValueError` is raised
- improved C library shutdown management
- introduced some utility methods to `epr.Product` and `epr.Record` classes

## PyEPR 0.1 (09/03/2011)

Initial release

### Navigation

- index
- modules |
- previous |
- PyEPR 0.3 documentation »